@@ -3,8 +3,10 @@
 #' @description Calculate some stats about referrals
 #'
 #' @param waiting_list data.frame. A df of referral dates and removals
-#' @param start_date date. The start date to calculate from
-#' @param end_date date. The end date to calculate to
+#' @param start_date Date or character (in format 'YYYY-MM-DD'); The start date
+#'   to calculate from
+#' @param end_date Date or character (in format 'YYYY-MM-DD'); The end date to
+#'   calculate to
 #' @param referral_index the column index of referrals
 #'
 #' @return A data.frame with the following summary statistics on
@@ -32,6 +34,9 @@ wl_referral_stats <- function(waiting_list,
                               start_date = NULL,
                               end_date = NULL,
                               referral_index = 1) {
+  check_wl(waiting_list, referral_index)
+  check_date(start_date, end_date, .allow_null = TRUE)
+
   if (!is.null(start_date)) {
     start_date <- as.Date(start_date)
   } else {
