@@ -3,8 +3,10 @@
 #' @description Creates a simulated waiting list comprising referral dates,
 #' and removal dates
 #'
-#' @param start_date date. The start date for the simulation.
-#' @param end_date date. The end date for the simulation.
+#' @param start_date Date or character (in format 'YYYY-MM-DD'); The start date
+#'   to calculate from
+#' @param end_date Date or character (in format 'YYYY-MM-DD'); The end date to
+#'   calculate to
 #' @param demand numeric. Weekly demand (i.e., typical referrals per week).
 #' @param capacity numeric. Weekly capacity (i.e., typical removals per week).
 #' @param waiting_list data.frame. Waiting list where each row is a
@@ -59,16 +61,14 @@ wl_simulator <- function(
   demand = 10,
   capacity = 11,
   waiting_list = NULL,
-  withdrawal_prob = NA,
+  withdrawal_prob = NA_real_,
   detailed_sim = FALSE
 ) {
 
-  # check input type for WL
-  if (!is.null(waiting_list)) {
-    if (!methods::is(waiting_list, "data.frame")) {
-      stop("Waiting list is not supplied as a data.frame")}
-  }
-
+  check_date(start_date, end_date, .allow_null = TRUE)
+  check_class(demand, capacity, withdrawal_prob, .expected_class = "numeric")
+  check_class(detailed_sim, .expected_class = "logical")
+  if (!is.null(waiting_list)) check_wl(waiting_list)
 
   # Fix Start and End Dates
   if (is.null(start_date)) {
