@@ -4,8 +4,10 @@
 #'
 #' @param waiting_list data.frame. A df of referral dates and removals
 #' @param target_wait numeric. The required waiting time
-#' @param start_date date. The start date to calculate from
-#' @param end_date date. The end date to calculate to
+#' @param start_date Date or character (in format 'YYYY-MM-DD'); The start date
+#'   to calculate from
+#' @param end_date Date or character (in format 'YYYY-MM-DD'); The end date to
+#'   calculate to
 #'
 #' @return A data.frame of key waiting list summary statistics based on
 #'   queueing theory:
@@ -61,12 +63,9 @@ wl_stats <- function(waiting_list,
                      target_wait = 4,
                      start_date = NULL,
                      end_date = NULL) {
-
-  # Error handle
-  if (!methods::is(waiting_list, "data.frame")) {
-    stop("waiting list should be supplied as a data.frame")
-  }
-
+  check_wl(waiting_list)
+  check_class(target_wait, .expected_class = "numeric")
+  check_date(start_date, end_date, .allow_null = TRUE)
 
   if (nrow(waiting_list) == 0) {
     stop("No data rows in waiting list")
